==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/elastic/kotlin/inputs/UserInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.elastic.kotlin.inputs

import com.pulumi.azurenative.elastic.inputs.UserInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * User Information to be passed to partners.
 * @property companyInfo Company information of the user to be passed to partners.
 * @property companyName Company name of the user
 * @property emailAddress Email of the user used by Elastic for contacting them if needed
 * @property firstName First name of the user
 * @property lastName Last name of the user
 */
public data class UserInfoArgs(
    public val companyInfo: Output<CompanyInfoArgs>? = null,
    public val companyName: Output<String>? = null,
    public val emailAddress: Output<String>? = null,
    public val firstName: Output<String>? = null,
    public val lastName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.elastic.inputs.UserInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.elastic.inputs.UserInfoArgs =
        com.pulumi.azurenative.elastic.inputs.UserInfoArgs.builder()
            .companyInfo(companyInfo?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .companyName(companyName?.applyValue({ args0 -> args0 }))
            .emailAddress(emailAddress?.applyValue({ args0 -> args0 }))
            .firstName(firstName?.applyValue({ args0 -> args0 }))
            .lastName(lastName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserInfoArgs].
 */
@PulumiTagMarker
public class UserInfoArgsBuilder internal constructor() {
    private var companyInfo: Output<CompanyInfoArgs>? = null

    private var companyName: Output<String>? = null

    private var emailAddress: Output<String>? = null

    private var firstName: Output<String>? = null

    private var lastName: Output<String>? = null

    /**
     * @param value Company information of the user to be passed to partners.
     */
    @JvmName("jcrgdtufstumeoqv")
    public suspend fun companyInfo(`value`: Output<CompanyInfoArgs>) {
        this.companyInfo = value
    }

    /**
     * @param value Company name of the user
     */
    @JvmName("leqrplptqevgqstn")
    public suspend fun companyName(`value`: Output<String>) {
        this.companyName = value
    }

    /**
     * @param value Email of the user used by Elastic for contacting them if needed
     */
    @JvmName("pgxylmrqtrtqvuof")
    public suspend fun emailAddress(`value`: Output<String>) {
        this.emailAddress = value
    }

    /**
     * @param value First name of the user
     */
    @JvmName("nblrhjexnwmqphuo")
    public suspend fun firstName(`value`: Output<String>) {
        this.firstName = value
    }

    /**
     * @param value Last name of the user
     */
    @JvmName("xxyinlkogcybehrt")
    public suspend fun lastName(`value`: Output<String>) {
        this.lastName = value
    }

    /**
     * @param value Company information of the user to be passed to partners.
     */
    @JvmName("bxyltolsvsskadvl")
    public suspend fun companyInfo(`value`: CompanyInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.companyInfo = mapped
    }

    /**
     * @param argument Company information of the user to be passed to partners.
     */
    @JvmName("mhkglgxppbmsrkmc")
    public suspend fun companyInfo(argument: suspend CompanyInfoArgsBuilder.() -> Unit) {
        val toBeMapped = CompanyInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.companyInfo = mapped
    }

    /**
     * @param value Company name of the user
     */
    @JvmName("fwqeujrxfwksuljc")
    public suspend fun companyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.companyName = mapped
    }

    /**
     * @param value Email of the user used by Elastic for contacting them if needed
     */
    @JvmName("jugjikgfsvkdqchs")
    public suspend fun emailAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emailAddress = mapped
    }

    /**
     * @param value First name of the user
     */
    @JvmName("ejjghunsookrrtrb")
    public suspend fun firstName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.firstName = mapped
    }

    /**
     * @param value Last name of the user
     */
    @JvmName("hjojiyqjlbnngmsy")
    public suspend fun lastName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastName = mapped
    }

    internal fun build(): UserInfoArgs = UserInfoArgs(
        companyInfo = companyInfo,
        companyName = companyName,
        emailAddress = emailAddress,
        firstName = firstName,
        lastName = lastName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/elastic/kotlin/inputs/UserInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.elastic.kotlin.inputs

import com.pulumi.azurenative.elastic.inputs.UserInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * User Information to be passed to partners.
 * @property companyInfo Company information of the user to be passed to partners.
 * @property companyName Company name of the user
 * @property emailAddress Email of the user used by Elastic for contacting them if needed
 * @property firstName First name of the user
 * @property lastName Last name of the user
 */
public data class UserInfoArgs(
    public val companyInfo: Output<CompanyInfoArgs>? = null,
    public val companyName: Output<String>? = null,
    public val emailAddress: Output<String>? = null,
    public val firstName: Output<String>? = null,
    public val lastName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.elastic.inputs.UserInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.elastic.inputs.UserInfoArgs =
        com.pulumi.azurenative.elastic.inputs.UserInfoArgs.builder()
            .companyInfo(companyInfo?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .companyName(companyName?.applyValue({ args0 -> args0 }))
            .emailAddress(emailAddress?.applyValue({ args0 -> args0 }))
            .firstName(firstName?.applyValue({ args0 -> args0 }))
            .lastName(lastName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserInfoArgs].
 */
@PulumiTagMarker
public class UserInfoArgsBuilder internal constructor() {
    private var companyInfo: Output<CompanyInfoArgs>? = null

    private var companyName: Output<String>? = null

    private var emailAddress: Output<String>? = null

    private var firstName: Output<String>? = null

    private var lastName: Output<String>? = null

    /**
     * @param value Company information of the user to be passed to partners.
     */
    @JvmName("xltlthdoidecibkp")
    public suspend fun companyInfo(`value`: Output<CompanyInfoArgs>) {
        this.companyInfo = value
    }

    /**
     * @param value Company name of the user
     */
    @JvmName("oolwuedmiaevesfc")
    public suspend fun companyName(`value`: Output<String>) {
        this.companyName = value
    }

    /**
     * @param value Email of the user used by Elastic for contacting them if needed
     */
    @JvmName("binkledtqesalwqv")
    public suspend fun emailAddress(`value`: Output<String>) {
        this.emailAddress = value
    }

    /**
     * @param value First name of the user
     */
    @JvmName("hshymgrxmvhlahvu")
    public suspend fun firstName(`value`: Output<String>) {
        this.firstName = value
    }

    /**
     * @param value Last name of the user
     */
    @JvmName("hixborcdqaobsjej")
    public suspend fun lastName(`value`: Output<String>) {
        this.lastName = value
    }

    /**
     * @param value Company information of the user to be passed to partners.
     */
    @JvmName("wvkerymqrxqfphll")
    public suspend fun companyInfo(`value`: CompanyInfoArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.companyInfo = mapped
    }

    /**
     * @param argument Company information of the user to be passed to partners.
     */
    @JvmName("vkckpvuibogtdths")
    public suspend fun companyInfo(argument: suspend CompanyInfoArgsBuilder.() -> Unit) {
        val toBeMapped = CompanyInfoArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.companyInfo = mapped
    }

    /**
     * @param value Company name of the user
     */
    @JvmName("fulyovbanvlerstw")
    public suspend fun companyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.companyName = mapped
    }

    /**
     * @param value Email of the user used by Elastic for contacting them if needed
     */
    @JvmName("lxtogirldqcmyggj")
    public suspend fun emailAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.emailAddress = mapped
    }

    /**
     * @param value First name of the user
     */
    @JvmName("nvgdjjowwnsijuqb")
    public suspend fun firstName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.firstName = mapped
    }

    /**
     * @param value Last name of the user
     */
    @JvmName("gtukocixdiwycesq")
    public suspend fun lastName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastName = mapped
    }

    internal fun build(): UserInfoArgs = UserInfoArgs(
        companyInfo = companyInfo,
        companyName = companyName,
        emailAddress = emailAddress,
        firstName = firstName,
        lastName = lastName,
    )
}
